"use strict";
/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const domexception_1 = require("./domexception");
class Location {
    hash;
    host;
    hostname;
    href;
    origin;
    pathname;
    port;
    protocol;
    search;
    /** */
    constructor(href) {
        const url = new URL(href);
        url.username = '';
        url.password = '';
        Object.defineProperties(this, {
            hash: {
                get() {
                    return url.hash;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.hash".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            host: {
                get() {
                    return url.host;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.host".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            hostname: {
                get() {
                    return url.hostname;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.hostname".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            href: {
                get() {
                    return url.href;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.href".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            origin: {
                get() {
                    return url.origin;
                },
                enumerable: true,
            },
            pathname: {
                get() {
                    return url.pathname;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.pathname".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            port: {
                get() {
                    return url.port;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.port".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            protocol: {
                get() {
                    return url.protocol;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.protocol".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            search: {
                get() {
                    return url.search;
                },
                set() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot set "location.search".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            ancestorOrigins: {
                get() {
                    return {
                        length: 0,
                        item: () => null,
                        contains: () => false,
                    };
                },
                enumerable: true,
            },
            assign: {
                value: function assign() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot call "location.assign()".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            reload: {
                value: function reload() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot call "location.reload()".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            replace: {
                value: function replace() {
                    throw new domexception_1.default(
                    // eslint-disable-next-line quotes
                    `Cannot call "location.replace()".`, 'NotSupportedError');
                },
                enumerable: true,
            },
            toString: {
                value: function toString() {
                    return url.href;
                },
                enumerable: true,
            },
        });
    }
}
exports.default = Location;
//# sourceMappingURL=location.js.map