"use strict";
/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const types_1 = require("util/types");
const path_1 = require("path");
const vm = require("vm");
const context_1 = require("./context");
/** Executes the code in a new VM context */
async function run(task) {
    if (!Object.prototype.hasOwnProperty.call(vm, 'SourceTextModule')) {
        throw new Error('Modules support requires the --experimental-vm-modules flag');
    }
    const context = vm.createContext((0, context_1.createContext)(task.cwd, task.urlPathname, task.config));
    const module = new vm.SourceTextModule(task.code.toString(), {
        identifier: (0, path_1.join)(task.cwd, task.scriptName),
        context,
    });
    await module.link((async () => undefined));
    await module.evaluate();
    if (Object.prototype.hasOwnProperty.call(module.namespace, 'default')) {
        if (typeof module.namespace.default === 'function' ||
            (0, types_1.isAsyncFunction)(module.namespace.default)) {
            return module.namespace.default(task.payload);
        }
        else {
            return Promise.resolve(module.namespace.default);
        }
    }
}
exports.run = run;
//# sourceMappingURL=run.js.map