"use strict";
/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fake_timers_1 = require("@jest/fake-timers");
const jest_mock_1 = require("jest-mock");
const jest_util_1 = require("jest-util");
const path_1 = require("path");
const vm = require("vm");
const context_1 = require("../src/context");
/** Jest runtime simulator environment */
class RuntimeSimulatorEnvironment {
    config;
    context;
    fakeTimers;
    fakeTimersModern;
    global;
    moduleMocker;
    /** */
    constructor(config) {
        this.config = config;
        this.context = (0, context_1.createContext)(require.main ? (0, path_1.join)(config.cwd, (0, path_1.dirname)(require.main.filename)) : '/', globalThis.urlPathname ?? '/api/test', this.config.testEnvironmentOptions);
        const global = (this.global = vm.runInContext('this', this.context));
        global.global = global;
        global.clearInterval = clearInterval;
        global.clearTimeout = clearTimeout;
        global.setInterval = setInterval;
        global.setTimeout = setTimeout;
        global.Buffer = Buffer;
        (0, jest_util_1.installCommonGlobals)(global, this.config.globals);
        this.moduleMocker = new jest_mock_1.ModuleMocker(global);
        const timerIdToRef = (id) => ({
            id,
            ref() {
                return this;
            },
            unref() {
                return this;
            },
        });
        const timerRefToId = (timer) => (timer && timer.id) || undefined;
        this.fakeTimers = new fake_timers_1.LegacyFakeTimers({
            config: this.config,
            global,
            moduleMocker: this.moduleMocker,
            timerConfig: { idToRef: timerIdToRef, refToId: timerRefToId },
        });
        this.fakeTimersModern = new fake_timers_1.ModernFakeTimers({
            config: this.config,
            global,
        });
    }
    /** @inheritDoc */
    async setup() {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const global = this.global;
        Object.assign(global, {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            ...this.config.testEnvironmentOptions?.globals,
            global,
            console: global.console,
            setTimeout: global.setTimeout,
            setInterval: global.setInterval,
            clearTimeout: global.clearTimeout,
            clearInterval: global.clearInterval,
        });
    }
    /** @inheritDoc */
    async teardown() {
        this.fakeTimers?.dispose();
        this.fakeTimersModern?.dispose();
        this.context = null;
        this.fakeTimers = null;
        this.fakeTimersModern = null;
    }
    /** @inheritDoc */
    getVmContext() {
        return this.context;
    }
}
exports.default = RuntimeSimulatorEnvironment;
//# sourceMappingURL=index.js.map